R.Version()

setwd("./")
print(paste("The working directory is:", getwd()))

library(tools)
library(spatstat) # spatial point pattern analysis
library(spdep) # spatial statistics
library(raster) # raster operations
library(rgeos) # import export of geographical data
library(ggplot2) # graphing and visualising
library(ggmap) # mapping in ggplot
library(ggsn) # map furniture
library(sp)
library(grid) # manipulate ggplot2 objects
library(gtable)# manipulate ggplot2 objects
library(gridExtra) # graphing and visualising
library(ggExtra) # graphing and visualising
library(lattice) # graphing and visualising
library(maptools) # tools to manipulate geographical data
library(rgdal) # manipulate raster images
library(rgl) # 3-D visualisation
library(lmtest)
library(pgirmess) # kruskal wallis multi component analysis; load pgirmess library
library(extrafont) #load fonts for Plos One
library(rgrass7)
library(gstat)
library(doBy) # summary stats
library(dunn.test) #post hoc tests after Kruskal Wallis
library(plotly) # generate interactive maps

if(!dir.exists("./Data"))unzip("Datasets.zip", exdir = "./Data")
if(!dir.exists("./grassdata"))unzip("grassdata.zip", exdir = "./grassdata")
dir.create("./Results")

fc.data <- readOGR(dsn = "./Data", "BtDistUTM", integer64 = "warn.loss", stringsAsFactors = FALSE) # data is in UTM 44North EPSG 32644
fc.data$mesh1mm <- as.numeric(fc.data$mesh1mm) ## NAs are for line and hook
fdf <- as.data.frame(fc.data) # ggplot only works on dataframes
spatial.df<-read.csv("./Data/spatial2017.csv", stringsAsFactors=FALSE) # cleaned data for npstat.R

g_legend<-function(a.gplot){
tmp <- ggplot_gtable(ggplot_build(a.gplot))
leg <- which(sapply(tmp$grobs, function(x) x$name) == "guide-box")
legend <- tmp$grobs[[leg]]
return(legend)
}

eps.tiff <- function(plot.cmd, flnm, width.in, height.in){
  tiff(filename = paste0(flnm, ".tiff"),
    width = width.in, height = height.in,
    units = "in", compression = "lzw", pointsize = 12, res = 450, family = "Arial",
    type = "cairo", antialias="subpixel")
  plot(plot.cmd)
  dev.off()
  cairo_ps(filename = paste0(flnm, ".eps"),
    width = width.in, height = height.in, pointsize = 12,
    onefile = FALSE, family = "Arial", bg = "white",
    antialias = "subpixel", fallback_resolution =450)
  plot(plot.cmd)
dev.off()
}

get.weights <- function(long, lat){
    xy <- cbind(long, lat)
    map_nb <<- knn2nb(knearneigh(xy, longlat=TRUE))
    map_nb <<- make.sym.nb(map_nb)
    map_w <<- nb2listw(map_nb,glist=NULL,style="W",zero.policy=FALSE)
    map_b <<- nb2listw(map_nb, glist=NULL, style="B", zero.policy=FALSE)
}

gry.test <- function(x){
  df <- as.data.frame(matrix(nrow=1, ncol=5))
  names(df) <- c("data.name", "Geary C statistic", "Expectation", "Variance", "p.value")
  gt <- geary.test(x, map_w, randomisation=TRUE, zero.policy=NULL, alternative="greater", spChk=NULL, adjust.n=TRUE)
  df[1,1] <- gt$data.name
  df[1,2:4] <- gt$estimate
  df[1,5] <- gt$p.value
  write.table(df,"./Results/GearyTest2.csv", append=TRUE, row.names=TRUE)
  return(df)
}

initGRASS(gisBase = "/usr/lib/grass74/", home = tempdir(), 
  gisDbase = "./grassdata",
  location = "fisheries", mapset = "craftdist", override = TRUE)

plot.panels <- function(panels){
craft.map <- ggmap(pdymap.bw,
		   base_layer = ggplot(aes(x = long, y = lat), data = fdf))  +
    geom_point(shape = 1) +
    labs(x = 'Longitude', y = 'Latitude') +
    facet_wrap(as.formula(paste("~", panels)))
    ggsave(filename = paste0(panels, ".png"))
    }

qmplot.panels <- function(panels){
craft.map <- qmplot(long, lat, data = fdf, maptype = "toner-lite", extent = "panel")  +
    geom_point(shape = 1) +
    theme(plot.caption = element_text(colour="black", size=6, face="bold"),
    axis.text = element_text(colour="black", size=7)) +
    labs(x = 'Longitude', y = 'Latitude', caption = "NOT TO SCALE") +
    facet_wrap(as.formula(paste("~", panels)))
ggsave(filename = paste0("./Results/PlotPanel", panels, ".png"))
print(craft.map)
}

subset.map <- function(map.list, colhd){
map.out <- gsub(" ", "", map.list, fixed = TRUE) #remove whitespace
map.out <- paste0(map.out,"_",colhd) # append col name to output map
execGRASS("v.extract", input="BtDistUTM@PERMANENT", type="point",
          where = paste0(colhd, " = \'", map.list,"\'"),
          output=map.out, flags = "overwrite", intern = TRUE)
	  }

subsetmesh <- function(lwr, upr, nm){
query <- paste("meshsize >=", lwr, "and meshsize <", upr)
execGRASS("v.extract", input="BtDistUTM@PERMANENT",
type="point", where=query,
          output=nm, flags = "overwrite")
	  }

build.quads <- function(x, y){
execGRASS("v.select", parameters = list (ainput="onekmgrid@craftdist", atype="area", binput=x, btype=c("point","area"), output="quad1k@craftdist", operator="contains"), flags = "overwrite") # select only those grids with boats
## see if a table exists
if(identical(execGRASS("v.db.connect", flags = "c", map = x, intern=TRUE), character(0)))
execGRASS("v.db.addtable", map=x, columns="tot_boats INT") # create table and add col
## execGRASS("v.db.addcolumn", map=x, columns="tot_boats INT") #add column if table exists
if(execGRASS("v.info", map=x, flags = "t", intern = TRUE)[2] != "points=0"){
execGRASS("v.vect.stats", parameters = list(points=x, areas="quad1k@craftdist", count_column="count", method="sum", points_column="tot_boats", stats_column="sum_bts"))
## count the points in each grid
    execGRASS("v.extract", input="quad1k@craftdist", type="centroid", output="quad1kcent@craftdist", flags = "overwrite")
    execGRASS("v.type", input="quad1kcent@craftdist", output=y, from_type="centroid", to_type="point", flags = "overwrite") # generate a centroid map
    }else{
    print("layer is empty")
    }
    }

run.idw <- function(x, y){
boatdens <- readVECT(x, plugin=NULL)
bt.ll <- spTransform(boatdens,  CRS("+proj=longlat +datum=WGS84")) # change crs to lat long
## bt.ll$efrt <- bt.ll$sum_bts
## bt.pp <- as.ppp(bt.ll)
grd <- as.data.frame(spsample(bt.ll, "regular", n=100000))
names(grd) <- c("x", "y")
coordinates(grd) <- c("x", "y")
gridded(grd) <- TRUE  # Create SpatialPixel object
fullgrid(grd) <- TRUE  # Create SpatialGrid object
proj4string(grd) <- CRS(proj4string(bt.ll)) 
## Interpolate the surface using a power value of 2 (idp=2.0)
dat.idw <- gstat::idw(sum_bts~1,bt.ll,newdata=grd,idp=2.0)
idw.df <- as.data.frame(dat.idw)
idw.df$facet <- y
return(idw.df)
}

plot.quadcount <- function(plot.data){
ggdat <<- plot.data
plot <- ggmap(pdymap.bw, base_layer = ggplot(aes(x = x, y = y, z = var1.pred), data=ggdat)) +
facet_wrap( ~ facet, ncol = 3) +
geom_raster(aes(alpha=var1.pred))+    
    labs(alpha = "Boats/km2", x = "long", y = "lat") +
    geom_contour(alpha = .25) +
    coord_equal()
    return(plot)
    }

qmplot.quadcount <- function(ggdat){
plot <- qmplot(x = x, y = y, data = ggdat, maptype = "toner-lite", extent = "panel", alpha = I(.0)) +
    theme(plot.caption = element_text(colour="black", size=6, face="bold")) +
    theme(axis.text = element_text(colour="black", size=7)) +
    labs(alpha = "Boats/km2", x = 'Longitude', y = 'Latitude', caption = "NOT TO SCALE") +
    facet_wrap( ~ facet) +
    geom_raster(aes(alpha=var1.pred))+
    geom_contour(alpha = .25, aes(x = x, y = y, z = var1.pred)) +
    coord_equal()
    return(plot)
    }

read.vect.list <- function(x, facet.x){
vect.x <- readVECT(x)
df.x <- as.data.frame(vect.x)    
df.x$facet <- facet.x
return(df.x)
}

qmplot.dens2d.mesh <- function(ggdat, fig.filename){
out <- by(data = ggdat, INDICES = ggdat$facet, FUN = function(m) {
    m <- droplevels(m)
    qmplot(x = long, y = lat, data = ggdat, maptype = "toner-lite", extent = "panel", zoom=10, geom="text", label="") + # force extents to fit data locations #qmplot
        geom_point(data = m, aes(x = long, y = lat, colour=meshsize)) +
        stat_density2d(data = m, aes(x = long, y = lat)) +
        labs(
            x = NULL,
            y = NULL ,
            title = m$facet[1],
            colour = "Mesh \nSize (mm)",
            caption = NULL # "Not to scale."
        ) +
        coord_equal()
})
grb.out <- do.call(arrangeGrob, c(out, list(ncol=3, padding = 0)))
x.lab <- textGrob("Longitude", gp=gpar(fontsize=14))
y.lab <- textGrob("Latitude", rot=90,gp=gpar(fontsize=14))
grid.arrange(grb.out, left=y.lab, bottom=x.lab, widths=c(100, 0.5, 0.0))

if(file_ext(fig.filename)=="tiff"){
    ## fig.file <-
    tiff(filename = fig.filename, width = 12, height = 9,
         units = "in", compression = "lzw", pointsize = 12, res = 300, family = "Arial",
         type = "cairo", antialias="subpixel")
    grid.arrange(grb.out, left=y.lab, bottom=x.lab, widths=c(100, 0.5, 0.0))
    dev.off()
}else{
    cairo_ps(filename = fig.filename, width = 12, height = 9, pointsize = 12,
             onefile = FALSE, family = "Arial", bg = "white",
             antialias = "subpixel", fallback_resolution =600)
    grid.arrange(grb.out, left=y.lab, bottom=x.lab, widths=c(100, 0.5, 0.0))
    dev.off()
  }
}

summaryBy(mesh1mm~fishery,data = spatial.df, FUN=c(median, sd, mean), na.rm=TRUE)

summaryBy(depth_m~fishery,data = spatial.df, FUN=c(median, sd, mean), na.rm=TRUE)

summaryBy(shoredist_km~fishery,data = spatial.df, FUN=c(median, sd, mean), na.rm=TRUE)

summaryBy(mesh1mm~boat_type1,data = spatial.df, FUN=c(median, sd, mean), na.rm=TRUE)

summaryBy(depth_m~boat_type1,data = spatial.df, FUN=c(median, sd, mean), na.rm=TRUE)

summaryBy(shoredist_km~boat_type1,data = spatial.df, FUN=c(median, sd, mean), na.rm=TRUE)

p <- ggplot(spatial.df, aes(depth_m, shoredist_km)) + geom_point() + theme_classic()
ggExtra::ggMarginal(p, type = "histogram")

ggplot(spatial.df, aes(shoredist_km)) + geom_freqpoly(bins = 20)

ggplot(spatial.df, aes(depth_m)) + geom_histogram(bins = 20)

ggplot(spatial.df, aes(mesh1mm)) + geom_freqpoly(bins = 10)

ggplot(spatial.df, aes(shoredist_km, depth_m)) + geom_point()

ggplot(spatial.df,aes(fishery, depth_m)) + stat_boxplot(geom ='errorbar') + geom_boxplot(notch = TRUE) #, outlier.shape=NA)
p<-ggplot(spatial.df,aes(fishery, shoredist_km)) + stat_boxplot(geom ='errorbar') + geom_boxplot(notch = TRUE, coef = 1.5, outlier.shape=NA) + scale_y_continuous(limits = c(0, 38))
b<- p + xlab("Fishery") + ylab("Distance to shore (km)") + ggtitle("Distance to Shore") 
c<-b + theme(axis.title.x = element_blank(), axis.title.y = element_text(face="plain", size=12))
d<-c + theme(axis.text = element_text(size=10, face="plain"))
e<-d + theme(plot.title = element_text(size = 12, face = "plain", hjust = 0.5))
e

f<-ggplot(spatial.df,aes(fishery, depth_m)) + stat_boxplot(geom ='errorbar') + geom_boxplot(notch = TRUE, coef = 1.5, outlier.shape=NA) + scale_y_continuous(limits = c(0, 70))
g<- f + xlab("Fishery") + ylab("Bottom depth (m)") + ggtitle("Depth of Operation") 
h<-g + theme(axis.title.x = element_blank(), axis.title.y = element_text(face="plain", size=12))
i<-h + theme(axis.text = element_text(size=10, face="plain"))
j<-i + theme(plot.title = element_text(size = 12, face = "plain", hjust = 0.5))
j

plot.cmd <- grid.arrange(e, j,  layout_matrix = matrix(c(1,2), ncol=2, byrow=TRUE))
flnm <- "./Results/FishingDistancesDepth_byGear"
eps.tiff(plot.cmd, flnm, width.in = 12, height.in = 6)
plot.cmd

ggplot(spatial.df,aes(boat_type1, depth_m)) + stat_boxplot(geom ='errorbar') + geom_boxplot(notch = TRUE)  #, outlier.shape=NA)
p<-ggplot(spatial.df,aes(boat_type1, shoredist_km)) + stat_boxplot(geom ='errorbar') + geom_boxplot(notch = TRUE, coef = 1.5, outlier.shape=NA) + scale_y_continuous(limits = c(0, 35))
p
b<- p + xlab("Type of fishing craft") + ylab("Distance to shore (km)") + ggtitle("Distance to Shore") + scale_x_discrete(breaks=c("frp", "frp_big", "kattumaram","trawl","vallam"), labels=c("Small FRP", "Big FRP", "Kattumaram", "Trawler", "Vallam"))
c<-b + theme(axis.title.x = element_blank(), axis.title.y = element_text(face="plain", size=12))
d<-c + theme(axis.text = element_text(size=10, face="plain"))
e<-d + theme(plot.title = element_text(size = 12, face = "plain", hjust = 0.5))
e

f<-ggplot(spatial.df,aes(boat_type1, depth_m)) + stat_boxplot(geom ='errorbar') + geom_boxplot(notch = TRUE, coef = 1.5, outlier.shape=NA) + scale_y_continuous(limits = c(0, 65))
f
g<- f + xlab("Type of fishing craft") + ylab("Bottom depth (m)") + ggtitle("Depth of Operation") + scale_x_discrete(breaks=c("frp", "frp_big", "kattumaram","trawl","vallam"), labels=c("Small FRP", "Big FRP", "Kattumaram", "Trawler", "Vallam"))
h<-g + theme(axis.title.x = element_blank(), axis.title.y = element_text(face="plain", size=12))
i<-h + theme(axis.text = element_text(size=10, face="plain"))
j<-i + theme(plot.title = element_text(size = 12, face = "plain", hjust = 0.5))
j

plot.cmd <- grid.arrange(e, j, layout_matrix = matrix(c(1,2), ncol=2, byrow=TRUE))
flnm <- "./Results/FishingDistancesDepth_byCraft"
eps.tiff(plot.cmd, flnm, width.in = 12, height.in = 6)
plot.cmd

ggplot(spatial.df,aes(boat_type1, mesh1mm)) + stat_boxplot(geom ='errorbar') + geom_boxplot(notch = TRUE)  #, outlier.shape=NA)
p<-ggplot(spatial.df,aes(fishery, mesh1mm)) + stat_boxplot(geom ='errorbar') + geom_boxplot(notch = TRUE, coef = 1.5, outlier.shape=NA) + scale_y_continuous(limits = c(0, 115))
b<- p + xlab("Fishery") + ylab("Mesh size (mm)") + ggtitle("Fishery") 
c<-b + theme(axis.title.x = element_blank(), axis.title.y = element_text(face="plain", size=12))
d<-c + theme(axis.text = element_text(size=10, face="plain"))
e<-d + theme(plot.title = element_text(size = 12, face = "plain", hjust = 0.5))
e

f<-ggplot(spatial.df,aes(boat_type1,  mesh1mm)) + stat_boxplot(geom ='errorbar') + geom_boxplot(notch = TRUE, coef = 1.5, outlier.shape=NA) + scale_y_continuous(limits = c(0, 115))
f
g<- f + xlab("Type of fishing craft") + ylab("Mesh size (mm)") + ggtitle("Craft") + scale_x_discrete(breaks=c("frp", "frp_big", "kattumaram","trawl","vallam"), labels=c("Small FRP", "Big FRP", "Kattumaram", "Trawler", "Vallam"))
h<-g + theme(axis.title.x = element_blank(), axis.title.y = element_text(face="plain", size=12))
i<-h + theme(axis.text = element_text(size=10, face="plain"))
j<-i + theme(plot.title = element_text(size = 12, face = "plain", hjust = 0.5))
j

plot.cmd <- grid.arrange(e, j, layout_matrix = matrix(c(1,2), ncol=2, byrow=TRUE))
flnm <- "./Results/MeshSizesAcrossFisheriesAndCraft"
eps.tiff(plot.cmd, flnm, width.in = 12, height.in = 6)
plot.cmd

spatial.df$fishery.f <- as.factor(spatial.df$fishery)
kruskal.test(depth_m ~ fishery.f, data = spatial.df)

kruskal.test(shoredist_km ~ fishery.f, data = spatial.df)

kruskal.test(mesh1mm ~ fishery.f, data = spatial.df)

spatial.df$boat_type1.f <- as.factor(spatial.df$boat_type1)
kruskal.test(depth_m ~ boat_type1.f, data = spatial.df)

kruskal.test(shoredist_km ~ boat_type1.f, data = spatial.df)

kruskal.test(mesh1mm ~ boat_type1.f, data = spatial.df)

spatial.df$region.f <- as.factor(spatial.df$region)
kruskal.test(depth_m ~ region.f, data = spatial.df)

kruskal.test(shoredist_km ~ region.f, data = spatial.df)

kruskal.test(mesh1mm ~ region.f, data = spatial.df)

dunn.test (spatial.df$shoredist_km, g=spatial.df$fishery, method="bh", kw=TRUE, label=TRUE, 
wrap=TRUE, table=TRUE, list=TRUE, rmc=FALSE, alpha=0.05)

dunn.test (spatial.df$depth_m, g=spatial.df$fishery, method="bh", kw=TRUE, label=TRUE, 
wrap=FALSE, table=TRUE, list=TRUE, rmc=FALSE, alpha=0.05)

dunn.test (spatial.df$mesh1mm, g=spatial.df$fishery, method="bh", kw=TRUE, label=TRUE, 
 wrap=FALSE, table=TRUE, list=TRUE, rmc=FALSE, alpha=0.05)

dunn.test (spatial.df$shoredist_km, g=spatial.df$boat_type1, method="bh", kw=TRUE, label=TRUE, 
wrap=FALSE, table=TRUE, list=TRUE, rmc=FALSE, alpha=0.05)

dunn.test (spatial.df$depth_m, g=spatial.df$boat_type1, method="bh", kw=TRUE, label=TRUE, 
wrap=FALSE, table=TRUE, list=TRUE, rmc=FALSE, alpha=0.05)

dunn.test (spatial.df$mesh1mm, g=spatial.df$boat_type1, method="bh", kw=TRUE, label=TRUE, 
wrap=FALSE, table=TRUE, list=TRUE, rmc=FALSE, alpha=0.05)

dunn.test (spatial.df$shoredist_km, g=spatial.df$region,  kw=TRUE, label=TRUE, 
wrap=FALSE, table=TRUE, list=TRUE, rmc=FALSE, alpha=0.05)

dunn.test (spatial.df$depth_m, g=spatial.df$region,  kw=TRUE, label=TRUE, 
wrap=FALSE, table=TRUE, list=TRUE, rmc=FALSE, alpha=0.05)

dunn.test (spatial.df$mesh1mm, g=spatial.df$region,  kw=TRUE, label=TRUE, 
wrap=FALSE, table=TRUE, list=TRUE, rmc=FALSE, alpha=0.05)

xy<-cbind(spatial.df$long, spatial.df$lat)
colnames(xy) <- c("LONG","LAT")
map_nb <-knn2nb(knearneigh(xy, longlat=TRUE))
map_nb <-make.sym.nb(map_nb)
map_nb

map_w <- nb2listw(map_nb,glist=NULL,style="W",zero.policy=FALSE)
map_w

map_b <- nb2listw(map_nb, glist=NULL, style="B", zero.policy=FALSE)
map_b

gry.test(spatial.df$motor_hp1)

gry.test(spatial.df$depth_m)

gry.test(spatial.df$shoredist_km)

gry.test(spatial.df$boat_length1)

gry.test(spatial.df$crew_size)

spat.df <- subset(spatial.df, !is.na(mesh1mm))
xy<-cbind(spat.df$long, spat.df$lat)
colnames(xy) <- c("LONG","LAT")
plot(xy)
map_nb <-knn2nb(knearneigh(xy, longlat=TRUE))
map_nb <-make.sym.nb(map_nb)
map_w <- nb2listw(map_nb, glist=NULL, style="W", zero.policy=FALSE)
map_b <- nb2listw(map_nb, glist=NULL, style="B", zero.policy=FALSE)

geary.test(spat.df$mesh1mm, map_w) # removed na.action=na.omit)
geary.test(spat.df$mesh1mm, map_w, zero.policy=NULL, 
alternative = "greater", spChk=NULL) # na.action=na.exclude, , p.adjust.method="bh"

spat.df$boat_type1.f <- as.factor(spat.df$boat_type1)
jcmulti.craft <- joincount.multi(spat.df$boat_type1.f, map_w, zero.policy = FALSE, spChk = NULL, adjust.n=TRUE)
jcmulti.craft <- as.data.frame(jcmulti.craft)
colnames(jcmulti.craft)[4] <- "z.value"
jcmulti.craft$p.value <- pnorm(-abs(jcmulti.craft$z.value))
jcmulti.craft$adjusted.p.value <- p.adjust(jcmulti.craft$p.value, "fdr")
write.csv(jcmulti.craft, file="./Results/jc_multi_craft.csv")
jcmulti.craft

spat.df$fishery.f <- as.factor(spat.df$fishery)
jcmulti.fy <- joincount.multi(spat.df$fishery.f, map_w, zero.policy = FALSE, spChk = NULL, adjust.n=TRUE)
jcmulti.fy <- as.data.frame(jcmulti.fy)
colnames(jcmulti.fy)[4] <- "z.value"
jcmulti.fy$p.value <- pnorm(-abs(jcmulti.fy$z.value))
jcmulti.fy$adjusted.p.value <- p.adjust(jcmulti.fy$p.value, "fdr")
write.csv(jcmulti.fy, file="./Results/jc_multi_fy.csv")
jcmulti.fy

globalG.test(spat.df$mesh1mm, map_b)

Gmesh <- localG(spat.df$mesh1mm, map_b, zero.policy=NULL, spChk=NULL)
summary(Gmesh)

Gcrew <- localG(spat.df$crew_size, map_b)
summary(Gcrew)

mech <- subset(spatial.df, sector == "mech")
mechboats<-c('trawl' = "Trawler", 'vallam' = "Vallam")
sp <- ggplot(mech, aes(x=shoredist_km,y=depth_m, colour = factor (distvio))) + geom_point(shape=21, position=position_jitter(width=0.5,height=0.5))
sp
a<-sp + scale_colour_manual(name="Violation of shore distance (km)", labels=c("> 5.556km","< 5.556km"), values = c("dark grey", "black"))
b<-a + facet_grid(region ~ boat_type1, labeller = labeller(boat_type1 = as_labeller(mechboats)))
b
c<-b + ggtitle("Violation of fishing 3 nautical miles (5.556 km) from the shore by mechanized craft") + xlab("Distance from shore (km)") + ylab("Depth of substrate(m)")
d<-c + theme(strip.text.x = element_text(size=12, face="bold"), strip.text.y = element_text(size=12, face="bold"))
e<-d + theme(legend.position = "bottom")
f<-e + theme(axis.text = element_text(size=12, face="bold"))
g<-f + theme(axis.title.x = element_text(face="bold", size=14), axis.title.y = element_text(face="bold", size=14))
g

mesh <- ggplot(spatial.df, aes(x=shoredist_km, y=depth_m, colour = factor (meshvio))) + geom_point(shape=21, position=position_jitter(width=0.5,height=0.5)) + facet_wrap(~region)
c<-mesh + ggtitle("Violation of gear mesh sizes") + xlab("Distance from shore (km)") + ylab("Depth of substrate(m)")
d<-c + theme(strip.text.x = element_text(size=12, face="bold"), strip.text.y = element_text(size=12, face="bold"))
e<-d + theme(legend.position = "bottom")
f<-e + theme(axis.text = element_text(size=12, face="bold"))
g<-f + theme(axis.title.x = element_text(face="bold", size=14), axis.title.y = element_text(face="bold", size=14))
g + scale_colour_manual(name="Violation of gear mesh sizes(mm)", labels=c("No","Yes"), values = c("grey", "black")) + scale_size_continuous(name  ="Mesh sizes(mm)")
## creating groups to bin mesh sizes going from 0  to 120 in increments of 20.
spatial.df$mesh1mmcat<-cut(spatial.df$mesh1mm, seq(0,120,20))
## renaming the facet panels
meshcat<-c(
  '(0,20]' = "0-20",
  '(20,40]' = "20-40",
  '(40,60]' = "40-60",
  '(60,80]'= "60-80",
  '(80,100]'="80-100",
  '(100,120]'="100-120"
)
## plotting distribution of mesh sizes
p<-ggplot(spatial.df,aes(shoredist_km, depth_m, colour = factor(fishery))) +
    geom_point() +
    facet_wrap(~mesh1mmcat, scales = "free_x", labeller = labeller(mesh1mmcat = as_labeller(meshcat))) ## mesh1mmcat doesn't exit
q<- p + theme_gray() + geom_point(shape=21, position=position_jitter(width=0.5,height=0.5))
r<- q + ggtitle("Cumulative distribution of gear mesh sizes") + xlab("Distance from shore(km)") + ylab("Depth of substrate(m)")
s<- r + theme(legend.position = "bottom") + scale_colour_discrete(name  ="Fishery", 
								  breaks=c("Gillnet", "Lift","Line", "Ringseine", "Scoopnet","Trawl"),
								  labels=c("Gill net", "Lift net","Line", "Ring seine", "Scoop net","Trawl"))
t<-s + theme(axis.title.x = element_text(face="bold", size=14), axis.title.y = element_text(face="bold", size=14))
u<-t + theme(axis.text = element_text(size=12))
v<-u + theme(plot.title = element_text(size = 16, face = "bold")) + theme(strip.text.x = element_text(size=12, face="bold"))
x<-v + theme(legend.text = element_text(size=12)) + theme(legend.title = element_text(size=12, face = "bold"))
x

ggplt <- ggplot(data=fdf, aes(fdf$shoredist_)) +
  geom_vline(xintercept = 5.556, colour="black", linetype = "longdash") +
  geom_histogram(breaks=seq(1, 45, by =0.5), 
                 ## col="gray5", # uncomment if you want grayscale
                 aes(fill=..count..)) +
  labs(x="Distance (km)", y="Count") +
  ##    theme(plot.margin = unit(c(5,4,0.05,0.05), "in")) +
  scale_fill_gradient("Count", low = "gray60", high = "black")
  ggplt

ggplot(data=fdf, aes(fdf$shoredist_)) +
  facet_wrap (~boat_type1)+
  geom_vline(xintercept = 5.556, colour="black", linetype = "longdash") + 
  geom_histogram(breaks=seq(1, 45, by=1),
                 ## col="gray5",  # uncomment if you want grayscale
                 aes(fill=..count..)) +
  labs(x="Distance (km)", y="Count") +
  scale_fill_gradient("Count", low = "gray60", high = "black")

ggplot(data=fdf, aes(fdf$depth_m)) +
  facet_wrap (~boat_type1)+
  geom_histogram(breaks=seq(1, 115, by=2),
                 ## col="gray5",  # uncomment if you want grayscale
                 aes(fill=..count..)) +
  labs(x="Depth (m)", y="Count") +
  scale_fill_gradient("Count", low = "gray60", high = "black")

pon<-subset (fdf, region == "Pondicherry")
cud<- subset (fdf,region == "Cuddalore")
vil<- subset (fdf, region == "Villupuram")
tn<-rbind(cud, vil)

trawl<-subset (pon, boat_type1 == "Trawl")
frp<-subset(pon,boat_type1 == "FRP")
vallam<-subset(pon,boat_type1 == "Vallam")
kat<-subset(pon,boat_type1 == "Kattumaram")
frpb<-subset(pon,boat_type1 == "Big FRP")
ponart<-rbind(frp, kat, frpb)
ponmech<-rbind(vallam,trawl)

tntrawl <- subset(tn, boat_type1 == "Trawl")
tnfrp <- subset(tn,boat_type1 == "FRP")
tnvallam <- subset(tn,boat_type1 == "Vallam")
tnkat <- subset(tn,boat_type1 == "Kattumaram")
tnfrpb <- subset(tn,boat_type1 == "Big FRP")
tnart <- rbind(tnfrp, tnkat, tnfrpb)
tnmech <- rbind(tnvallam,tntrawl)

plt <- ggplot(ponmech,aes(x=shoredist_,y=depth_m, size=crew_size, colour = factor(shoredist_>5.556))) +
 theme_gray() +
 geom_point(shape=21, position=position_jitter(width=0.5,height=0.5)) + 
 facet_wrap (~boat_type1) +
 ggtitle("MFRA Violoations of Distance of Fishing from Shore: Pondicherry") +
 xlab("Distance from shore (km)") +
 ylab("Depth of substrate(km)") +
 theme(legend.title = element_text(size = 12), plot.title = element_text(size = 12, face = "plain", hjust = 0.5)) +
 theme(legend.position="right")

plt1.bw <- plt + scale_colour_manual(name="Violations",
  labels=c("< 5.556km","> 5.556km"), values = c("black", "darkgrey")) +
  theme(legend.title = element_text(size = 12), plot.title = element_text(size = 12, face = "plain", hjust = 0.5)) +
  scale_size_continuous(name  ="Size of crew") 
plt1.bw

plt1.col <- plt + scale_colour_manual(name="Violations",
				      labels=c("< 5.556km","> 5.556km"), values = c("red", "darkgreen")) +
    theme(legend.title = element_text(size = 12)) +
    scale_size_continuous(name  ="Size of crew")
plt1.col

plt <- ggplot(tnmech,aes(x=shoredist_,y=depth_m, size=crew_size, colour = factor(shoredist_>5.556)))+
geom_point(shape=1, position=position_jitter(width=0.5,height=0.5)) +
facet_wrap (~boat_type1) +
ggtitle("MFRA Violoations of Distance of Fishing from Shore: Tamil Nadu") +
xlab("Distance from shore (Km)") +
ylab("Depth of substrate(m)") +
theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5))

plt2.col <- plt  + scale_colour_manual(name="Violations",
labels=c("< 5.556km","> 5.556km"), values = c("red", "darkgreen")) +
scale_size_continuous(name  ="Size of crew")
plt2.col

plt2.bw <- plt  + scale_colour_manual(name="Violations",
labels=c("< 5.556km","> 5.556km"), values = c("black", "darkgrey"))+
scale_size_continuous(name  ="Size of crew")
plt2.bw

mylegend <- g_legend(plt1.col)
plot.cmd <- grid.arrange(arrangeGrob(plt1.col + theme(legend.position="none")+ xlab(""),
                      plt2.col + theme(legend.position="none"), nrow=2),
	  mylegend, ncol=2, widths=c(40, 6))
plot.cmd

mylegend <- g_legend(plt1.bw)
 plot.cmd <- grid.arrange(arrangeGrob(plt1.bw + theme(legend.position="none")+ xlab(""),
                       plt2.bw + theme(legend.position="none"), nrow=2),
	   mylegend, ncol=2, widths=c(40, 6))
flnm <- "./Results/violations_distance_tn_pdy_bw"
eps.tiff(plot.cmd, flnm, width.in = 9, height.in = 7.5)
plot.cmd

tnmesh1<-subset(tn, net_type != "line")
plt.tn <- ggplot(tnmesh1,aes(x=shoredist_,y=depth_m, size=mesh1mm, colour = factor(mesh1mm>10))) +
 geom_point(shape=1, position=position_jitter(width=0.5,height=0.5)) +
 facet_wrap (~boat_type1, nrow=1)+ggtitle("MFRA Tamil Nadu: Violations of Gear Mesh Sizes") +
 xlab("Distance from shore (Km)") +
 ylab("Depth of substrate(m)") +
 theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5))
 plt.tn.col <- plt.tn +  scale_colour_manual(name="Violations",
				   labels=c("< 10mm","> 10mm"), values = c("red", "darkgreen")) +
 scale_size_continuous(name  ="Mesh size(mm)")
 plt.tn.col

plt.tn.bw <- plt.tn.col +  scale_colour_manual(name="Violations",
				  labels=c("< 10mm","> 10mm"), values = c("black", "darkgrey")) +
 scale_size_continuous(name  ="Mesh size(mm)")
 plt.tn.bw

ponmesh1 <- subset(pon, net_type != "line")
   plt.pon <- ggplot(ponmesh1,aes(x=shoredist_,y=depth_m, size=mesh1mm, colour = factor(mesh1mm>25))) +
   geom_point(shape=1, position=position_jitter(width=0.5,height=0.5)) +
    facet_wrap (~boat_type1, nrow=1)+ggtitle("MFRA Pondicherry: Violoations of Gear Mesh Sizes") +
    xlab("Distance from shore (Km)") +
    ylab("Depth of substrate(m)") +
    theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5))
plt.col.pon <- plt.pon +  scale_colour_manual(name="Violations",
				      labels=c("< 25mm","> 25mm"), values = c("red", "darkgreen")) +
    scale_size_continuous(name  ="Mesh size(mm)")
plt.col.pon

plt.bw.pon <- plt.pon +  scale_colour_manual(name="Violations",
				     labels=c("< 25mm","> 25mm"), values = c("black", "darkgrey")) +
    scale_size_continuous(name  ="Mesh size(mm)")
plt.bw.pon

plot.cmd <- grid.arrange(arrangeGrob(plt.bw.pon + theme(legend.position="right")+ xlab("") ,
				     plt.tn.bw + theme(legend.position="right"), nrow=2))
flmn <- "./Results/all_violations_mesh_tn_pdy_col"
eps.tiff(plot.cmd, flnm, width.in = 9, height.in = 7.5)
plot.cmd

pgill1 <- subset (pon, net_type == "multigill")
pgill2 <- subset (pon,net_type == "monogill")
pongill <- rbind(pgill1, pgill2)
tngill1 <- subset (tn, net_type == "multigill")
tngill2 <- subset (tn,net_type == "monogill")
tngill <- rbind(tngill1, tngill2)
allgill <- rbind(pongill, tngill)

plt <- ggplot(pongill,aes(x=shoredist_,y=depth_m, size=mesh1mm, colour = factor(mesh1mm>25))) +
 geom_point(shape=1, position=position_jitter(width=0.5,height=0.5)) + facet_wrap (~boat_type1) +
 ggtitle("Gill net mesh sizes used for fishing in Pondicherry") +
 xlab("Distance from shore (km)") +
 ylab("Depth of substrate(m)") +
 theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5)) 
 plt.col <- plt + scale_colour_manual(name="Violations",
				  labels=c("< 25mm","> 25mm"), values = c("red", "darkgreen")) +
 scale_size_continuous(name  ="Mesh size(mm)")
plt.col # colour plot

plt.bw <- plt + scale_colour_manual(name="Violations",
 labels=c("< 25mm","> 25mm"), values = c("darkgrey", "black")) +
 scale_size_continuous(name  ="Mesh size(mm)")
plt.bw # grayscale plot

plt <- ggplot(allgill,aes(x=shoredist_,y=depth_m, size=mesh1mm, colour = factor(mesh1mm>25))) +
 geom_point(aes(shape=factor(region)), position=position_jitter(width=1,height=.5))+
 labs(shape="District")+
 facet_wrap (~boat_type1) +
 ggtitle("Gill net mesh size violations: Pondicherry MFRA") +
 xlab("Distance from shore (km)") + ylab("Depth of substrate(m)") +
 theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5))
pltpdy.col <- plt + scale_colour_manual(name="Violations",
                                     labels=c("< 25mm","> 25mm"), values = c("red", "darkgreen")) +
				     theme(legend.title = element_text(size = 12)) +
				     scale_size_continuous(name  ="Mesh size (mm)") +
				     scale_shape_discrete(solid=F)
 pltpdy.col # colour plot

pltpdy.bw <- plt + scale_colour_manual(name="Violations",
				    labels=c("< 25mm","> 25mm"), values = c("black", "darkgrey")) +
 theme(legend.title = element_text(size = 12)) +
 scale_size_continuous(name  ="Mesh size (mm)")+
 scale_shape_discrete(solid=F)
 pltpdy.bw # grayscale plot

plt <- ggplot(allgill,aes(x=shoredist_,y=depth_m, size=mesh1mm, colour = factor(mesh1mm>10))) +
 geom_point(aes(shape=factor(region)), position=position_jitter(width=0.5,height=0.5))+
 labs(shape="District")+
 facet_wrap (~boat_type1) +
 ggtitle("Gill net mesh size violations: Tamil Nadu MFRA") +
 xlab("Distance from shore (km)") + ylab("Depth of substrate(m)") +
 theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5))
 ## guides(fill=guide_legend(nrow=3,byrow=TRUE))
 plttn.col <- plt + scale_colour_manual(name="Violations",
				    labels=c("< 10mm","> 10mm"), values = c("red", "darkgreen")) +
 scale_size_continuous(name  ="Mesh size (mm)") + 
 scale_shape_discrete(solid=F)
 plttn.col # colour plot

plttn.bw <- plt + scale_colour_manual(name="Violations",
				   labels=c("< 10mm","> 10mm"), values = c("black", "darkgrey")) +
 scale_size_continuous(name  ="Mesh size (mm)") +
 scale_shape_discrete(solid=F) 
 plttn.bw # grayscale plot

mylegend <- g_legend(pltpdy.col)
pltpdy.col <- pltpdy.col + xlab("")
grid.arrange(arrangeGrob(pltpdy.col + theme(legend.position="none")+ xlab("") ,
    plttn.col + theme(legend.position="none"), nrow=2),
    mylegend, ncol=2, widths=c(40, 6))

mylegend <- g_legend(pltpdy.bw) 
grid.arrange(arrangeGrob(pltpdy.bw + theme(legend.position="none")+ xlab(""),
  plttn.bw + theme(legend.position="none"), nrow=2),
  mylegend,  ncol=2, widths=c(40, 6))

mtrawl<-subset(ponmech, net_type == "multitrawl")
mtrawler<-subset(ponmech, boat_type1 == "Trawl")
ca <- ggplot(mtrawl,aes(x=shoredist_,y=depth_m, size=mesh1mm, colour = factor(mesh1mm>37))) +
 geom_point(shape=1, position=position_jitter(width=0.5,height=0.5)) +
 facet_wrap (~boat_type1)+ggtitle("Pondicherry MFRA Violations of Trawl Net Mesh Sizes") +
 xlab("Distance from shore (km)") + ylab("Depth of substrate(m)") +
 theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5)) +
 scale_colour_discrete(name="Violations",labels=c("< 37mm","> 37mm")) +
 scale_size_continuous(name ="Mesh size(mm)")
ca

da <- ggplot(mtrawler,aes(x=shoredist_,y=depth_m, size=mesh1mm, colour = factor(no_days > 1))) +
  geom_point(shape=1, position=position_jitter(width=0.5,height=0.5)) +
  ggtitle("Pondicherry MFRA Violoations Multiday Trawl Fishing") +
  xlab("Distance from shore (km)") + ylab("Depth of substrate(m)") +
  theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5)) +
  scale_colour_discrete(name="MFRA violation of multiday fishing",labels=c("single day fishing","multiday fishing")) +
  scale_size_continuous(name  ="Mesh sizes used")
da # plot da

ea <- ggplot(tnmech,aes(x=shoredist_,y=depth_m, size=mesh1mm, colour = factor(no_days > 1))) +
 geom_point(shape=1,  position=position_jitter(width=0.5,height=0.5)) +
 facet_wrap (~boat_type1)+ggtitle("Tamil Nadu MFRA Violoations Multiday Trawl Fishing") +
 xlab("Distance from shore (km)") + ylab("Depth of substrate(m)") +
 theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5)) +
 scale_colour_discrete(name="Violations",labels=c("Single day fishing","multiday fishing")) +
 scale_size_continuous(name  ="Mesh sizes used")
 ea

ij <- ggplot(tnmech,aes(x=shoredist_,y=depth_m, size=motor_hp1,colour = factor(motor_hp1>150))) +
geom_point(shape=1,  position=position_jitter(width=1, height=1.5)) +
 facet_wrap (~boat_type1)+ggtitle("Tamil Nadu MFRA Violation of Engine Horsepower in Mechanised Craft") +
 xlab("Distance from shore (km)") + ylab("Depth of substrate(m)") +
 theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5)) +
 scale_colour_discrete(name="Violations", labels=c("Mechanised <150 HP","Deep sea >150 HP"))+
 scale_size_continuous(name ="Motor HP range")
ij

j <- ggplot(ponmech,aes(x=shoredist_,y=depth_m, size=motor_hp1, colour = factor(motor_hp1>150))) +
 geom_point(shape=1, position = position_jitter(width=1, height=1.5)) +
 facet_wrap (~boat_type1) +
 ggtitle("Pondicherry MFRA Violation of Engine Horsepower in Mechanised Craft") +
 xlab("Distance from shore (km)") + ylab("Depth of substrate(m)") +
 theme(legend.position="right", plot.title = element_text(size = 12, face = "plain", hjust = 0.5)) +
 scale_colour_discrete(name="Violations", labels=c("Mechanised <150 HP","Deep sea >150 HP")) +
 scale_size_continuous(name  ="Motor HP range")
j

pdymap.bw <- get_map(location = c(lon = 79.86308, lat=12.0), zoom = 9, source = "stamen", maptype = "toner-lite") 
plot(pdymap.bw)

fdf$zone[fdf$shoredist_>5.556] <- "Non-Artisanal > 3nm (5.556km)" # changed from 3km to 3nm or 5.556km
fdf$zone[fdf$shoredist_<=5.556] <- "Artisanal <= 3nm (5.556km)"
dist.map <- qmplot(long, lat, data = fdf, maptype = "toner-lite", colour =zone, extent = "panel") +
scale_colour_manual(values = c("black", "darkgrey")) +
theme(plot.caption = element_text(colour="black", size=6, face="bold")) +
labs(x = "Longitude", y = "Latitude", colour = "Zone", caption = "NOT TO SCALE")+
scalebar(fdf,dist = 10, dd2km = TRUE, model = 'WGS84', height = 0.0075, st.size = 2.5)
plot(dist.map)

qmplot.panels("net_type")

execGRASS("g.mapset", mapset="craftdist") # ensure you're in the correct mapset
execGRASS("g.region", vector="BtDistUTM@PERMANENT", res="1000") # select computational extent
execGRASS("v.mkgrid", parameters = list(map="onekmgrid", box=c(1000,1000)), flags = "overwrite") # create 1km grid extending over region
execGRASS("g.remove", type="vector", name="frp,frp_big,kattumaram,trawl,vallam,frp_big_boat_type1,frp_boat_type1,kattumaram_boat_type1,trawl_boat_type1,vallam_boat_type1", flags = "f") # clean up

fishery.maps <- list("Gillnet", "Lift", "Line", "Ringseine", "Scoopnet", "Trawl") # list of maps to be created
lapply(X = fishery.maps, FUN = subset.map, colhd = "fishery") # run the function

craft.maps <- as.list(as.character(unique(fdf$boat_type1)))
lapply(X = craft.maps, FUN = subset.map, colhd = "boat_type1")

craftclass.maps <- as.list(as.character(unique(fdf$CraftClass)))
lapply(X = craftclass.maps, FUN = subset.map, colhd = "CraftClass")

execGRASS("g.mapset", mapset="PERMANENT") #switch to PERMANENT mapset
try(execGRASS("v.db.addcolumn", map="BtDistUTM@PERMANENT", columns="meshsize INT"))#add integer column
execGRASS("v.db.update", map="BtDistUTM@PERMANENT", column="meshsize", query_column="mesh1mm") #copy values
execGRASS("g.mapset", mapset="craftdist") #switch back to craftdist mapset
lwr.mesh <- as.list(seq(0, 110, by= 20)) 
upr.mesh <- as.list(seq(20, 120, by= 20))
nm.mesh <- paste0("mesh",seq(20, 120, by=20))
execGRASS("g.remove", type = "vector", pattern = "mesh*", flags = "f", intern=TRUE) # remove existing maps HERE
mapply(FUN = subsetmesh, lwr=lwr.mesh, upr=upr.mesh, nm=nm.mesh)

CraftClass.maps <- as.list(execGRASS("g.list", type = "vector", pattern = "*CraftClass", mapset = "craftdist", intern = T))
CraftClass.facets <- gsub("_CraftClass", "", CraftClass.maps)
CraftClass.df <- do.call("rbind", mapply(read.vect.list, CraftClass.maps, CraftClass.facets, SIMPLIFY = FALSE))
qmplot.dens2d.mesh(CraftClass.df, "./Results/CraftClassMeshSizes.tiff")
qmplot.dens2d.mesh(CraftClass.df, "./Results/CraftClassMeshSizes.eps")
qmplot.dens2d.mesh(CraftClass.df, "./Results/CraftClassMeshSizes.png")

net.maps <- as.list(execGRASS("g.list", type = "vector", pattern = "*fishery", mapset = "craftdist", intern = T))
net.map.facets <- as.list(gsub("_fishery","", net.maps))
net.df <- do.call("rbind", mapply(read.vect.list, net.maps, net.map.facets, SIMPLIFY = FALSE))
qmplot.dens2d.mesh(net.df, "./Results/NetTypesMeshSizes.tiff")
qmplot.dens2d.mesh(net.df, "./Results/NetTypesMeshSizes.eps")
qmplot.dens2d.mesh(net.df, "./Results/NetTypesMeshSizes.png")

mesh.maps <- as.list(execGRASS("g.list", type = "vector", pattern = "mesh*", intern = T))
mesh.maps <- mesh.maps[c(3,4,5,6,1,2)]
mesh.map.facets <- as.list(paste(seq(0, 110, 20), "to", seq(20, 120, 20)))
mesh.df <- do.call("rbind", mapply(read.vect.list, mesh.maps, mesh.map.facets, SIMPLIFY = FALSE))
mesh.df$facet <- factor(mesh.df$facet, levels = c("0 to 20","20 to 40","40 to 60","60 to 80","80 to 100","100 to 120")) # fix order of facets
qmplot.dens2d.mesh(mesh.df, "MeshSizeClassesMeshSizes.tiff")
qmplot.dens2d.mesh(mesh.df, "MeshSizeClassesMeshSizes.eps")
qmplot.dens2d.mesh(mesh.df, "MeshSizeClassesMeshSizes.png")

boat.maps <- as.list(execGRASS("g.list", type = "vector", pattern = "*boat_type1", mapset = "craftdist", intern = T))
boat.map.facets <- as.list(gsub("_boat_type1","", boat.maps))
boats.df <- do.call("rbind", mapply(read.vect.list, boat.maps, boat.map.facets, SIMPLIFY = FALSE))
qmplot.dens2d.mesh(boats.df, "BoatTypeMeshSizes.tiff")
qmplot.dens2d.mesh(boats.df, "BoatTypeMeshSizes.eps")
qmplot.dens2d.mesh(boats.df, "BoatTypeMeshSizes.png")

p <- qmplot(x = long, y = lat, data = boats.df, maptype = "toner-lite", extent = "panel", zoom=10, geom="text", label="") +
	geom_point(data = boats.df, aes(x = long, y = lat, colour=meshsize, shape=boat_type1)) +
	stat_density2d(data = boats.df, aes(x = long, y = lat)) +
	labs(
	    x = NULL,
	    y = NULL ,
	    title = "Craft and Mesh Sizes",
	    colour = "Mesh \nSize (mm)",
	    shape = "Craft Type",
	    caption = NULL 
	) +
    coord_equal()
p <- ggplotly(p)
htmlwidgets::saveWidget(p, "CraftMeshsizePlotly.html")

p <- qmplot(x = long, y = lat, data = mesh.df, maptype = "toner-lite", extent = "panel", zoom=10, geom="text", label="") +
	geom_point(data = mesh.df, aes(x = long, y = lat, colour=meshsize, shape=facet)) +
	stat_density2d(data = mesh.df, aes(x = long, y = lat)) +
	labs(
	    x = NULL,
	    y = NULL ,
	    title = "Mesh Size Class and Mesh Sizes",
	    colour = "Mesh \nSize (mm)",
	    shape = "Mesh Size \nClass",
	    caption = NULL 
	) +
    coord_equal()
p <- ggplotly(p)
htmlwidgets::saveWidget(p, "MeshSizeClassMeshsizePlotly.html")

p <- qmplot(x = long, y = lat, data = net.df, maptype = "toner-lite", extent = "panel", zoom=10, geom="text", label="") +
	geom_point(data = net.df, aes(x = long, y = lat, colour=meshsize, shape=facet)) +
	stat_density2d(data = net.df, aes(x = long, y = lat)) +
	labs(
	    x = NULL,
	    y = NULL ,
	    title = "Net Types and Mesh Sizes",
	    colour = "Mesh \nSize (mm)",
	    shape = "Net Type",
	    caption = NULL 
	) +
    coord_equal()
p <- ggplotly(p)
htmlwidgets::saveWidget(p, "NetTypeMeshsizePlotly.html")

p <- qmplot(x = long, y = lat, data = CraftClass.df, maptype = "toner-lite", extent = "panel", zoom=10, geom="text", label="") +
	geom_point(data = CraftClass.df, aes(x = long, y = lat, colour=meshsize, shape=facet)) +
	stat_density2d(data = CraftClass.df, aes(x = long, y = lat)) +
	labs(
	    x = NULL,
	    y = NULL ,
	    title = "Class of Craft and Mesh Sizes",
	    colour = "Mesh \nSize (mm)",
	    shape = "Craft Class",
	    caption = NULL 
	) +
    coord_equal()
p <- ggplotly(p)
htmlwidgets::saveWidget(p, "CraftClassMeshsizePlotly.html")
